@@ -1,5 +1,20 @@
 #!/usr/bin/perl
 
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 #	Migration between gconf data version 0 to 1
 #
 #	In version 1, a new model has been created to store services and it
@@ -106,7 +121,7 @@ sub _addBaseServices
         $apachePort = 443;
     };
     my %adminService = ('name' => __d('eBox administration'),
-                        'description' => __d('eBox Administration Web Server'),
+                        'description' => __d('Zentyal Administration Web Server'),
                         'domain' => __d('ebox-services'),
                         'protocol' => 'tcp',
                         'sourcePort' => 'any',
