@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -45,26 +45,24 @@
 #            }
 #           ],
 #       },
-#
-#
 #     },
 #     {
-#        'id' => 'serv7867',
-#        'name' => 'ftp',
-#        'description' => 'File transfer protocol'
-#        'configuration' => {
-#            'model' => 'ServiceConfigurationTable',
-#            'values' => [
-#            {
-#                'source' => 'any',
-#                'protocol' => 'TCP',
-#                'destination' => '21:22',
-#                'id' => 'serv6891'
-#            }
-#            ],
-#        },
+#       'id' => 'serv7867',
+#       'name' => 'ftp',
+#       'description' => 'File transfer protocol'
+#       'configuration' => {
+#           'model' => 'ServiceConfigurationTable',
+#           'values' => [
+#           {
+#               'source' => 'any',
+#               'protocol' => 'TCP',
+#               'destination' => '21:22',
+#               'id' => 'serv6891'
+#           }
+#           ],
+#       },
 #     }
-#    ]
+#   ]
 
 package EBox::Services::Model::ServiceTable;
 
@@ -79,8 +77,6 @@ use EBox::Model::ModelManager;
 use EBox::Exceptions::Internal;
 use EBox::Exceptions::MissingArgument;
 
-
-
 use strict;
 use warnings;
 
@@ -99,7 +95,6 @@ sub new
 
 sub _table
 {
-
     my @tableHead =
     (
         new EBox::Types::Text(
@@ -130,9 +125,7 @@ sub _table
             'editable' => 1,
             'help'  => __('Tick this field if there is actually a service ' .
                 'on the machine using the ports configured for this service. ' .
-                'This helps eBox to know what ports are already busy')
-
-
+                'This helps Zentyal to know what ports are already busy')
 #            'hidden' => 1,
         ),
         new EBox::Types::HasMany (
@@ -143,8 +136,6 @@ sub _table
         )
     );
 
-
-
     my $dataTable =
     {
         'tableName' => 'ServiceTable',
@@ -171,10 +162,8 @@ sub _table
 #
 #        Overrides <EBox::Model::DataTable::_tailoredOrder>
 #
-#
 sub _tailoredOrder # (rows)
 {
-
     my ($self, $rows_ref) = @_;
 
     # Order rules per priority
@@ -184,7 +173,6 @@ sub _tailoredOrder # (rows)
                             @{$rows_ref};
 
     return \@orderedRows;
-
 }
 
 # Method: availablePort
@@ -227,6 +215,44 @@ sub availablePort
     return 1;
 }
 
+# Method: serviceFromPort
+#
+#       Get the service name that it's using a port.
+#
+# Parameters:
+#
+#   (POSITIONAL)
+#   protocol   - it can take one of these: tcp, udp
+#   port       - An integer from 1 to 65536 -> 22
+#
+# Returns:
+#   string - the service name, undef otherwise
+#
+sub serviceFromPort
+{
+    my ($self, $protocol, $port) = @_;
+
+    unless (defined($protocol)) {
+        throw EBox::Exceptions::MissingArgument('protocol');
+    }
+
+    unless (defined($port)) {
+        throw EBox::Exceptions::MissingArgument('port');
+    }
+
+    my $internals = $self->findAll('internal' => 1);
+
+    for my $id (@{$internals}) {
+        my $service = $self->row($id);
+        my $serviceConf = $service->subModel('configuration');
+        for my $subId (@{$serviceConf->findAllValue('destination' => $port)}) {
+            my $row = $serviceConf->row($subId);
+            return $service->valueByName('name') if ($row->valueByName('protocol') eq $protocol);
+        }
+    }
+
+    return undef;
+}
 # Method: addService
 #
 #   Add service to the services table. Note this method must exist
@@ -235,28 +261,28 @@ sub availablePort
 # Parameters:
 #
 #   (NAMED)
-#   name       - service's name
+#   name        - service's name
 #   description - service's description
-#   protocol   - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
-#   sourcePort - it can take:
-#               "any"
-#               An integer from 1 to 65536 -> 22
-#               Two integers separated by colons -> 22:25
+#   protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
+#   sourcePort  - it can take:
+#                   "any"
+#                   An integer from 1 to 65536 -> 22
+#                   Two integers separated by colons -> 22:25
 #   destinationPort - same as source
 #   internal - booelan, to indicate if the service is internal or not
 #   readOnly - the service can't be deleted or modified
-#   translationDomain - eBox module domain for i18
+#   translationDomain - Zentyal module domain for i18
 #
 #   Example:
 #
 #       'protocol' => 'tcp',
 #       'source' => 'any',
 #       'destination' => '21:22',
+#
 sub addService
 {
     my ($self, %params) = @_;
 
-
     my $id = $self->addRow(_serviceParams(%params));
 
     unless (defined($id)) {
@@ -271,8 +297,6 @@ sub addService
                     "Couldn't get ServiceConfigurationTable");
     }
 
-
-
     $serviceConf->setDirectory($self->{'directory'} . "/$id/configuration");
     $serviceConf->addRow(_serviceConfParams(%params));
 
@@ -305,6 +329,7 @@ sub addService
 #       'protocol' => 'tcp',
 #       'source' => 'any',
 #       'destination' => '21:22',
+#
 sub setService
 {
     my ($self, %params) = @_;
@@ -331,7 +356,6 @@ sub setService
                     "Couldn't get ServiceConfigurationTable");
     }
 
-
     $serviceConf->setDirectory($self->{'directory'} . "/$id/configuration");
     my @ids = @{$serviceConf->ids()};
     unless (@ids) {
@@ -341,11 +365,9 @@ sub setService
 
     my $idConf = $ids[0];
 
-
     my %confParams = _serviceConfParams(%params);
     $confParams{'id'} = $idConf;
     $serviceConf->setRow(1, %confParams);
-
 }
 
 # Method: addMultipleService
@@ -370,7 +392,6 @@ sub setService
 #                                   Two integers separated by colons -> 22:25
 #	    destinationPort - same as source
 #
-#
 #	Example:
 #
 #       'name' => 'ssh',
@@ -379,18 +400,19 @@ sub setService
 #                       {
 #	                        'protocol' => 'tcp',
 #	                        'sourcePort' => 'any',
-#                           'destinationPort' => '21:22'
+#                               'destinationPort' => '21:22'
 #                        },
 #                        {
 #	                        'protocol' => 'tcp',
 #	                        'sourcePort' => 'any',
-#                           'destinationPort' => '21:22'
+#                               'destinationPort' => '21:22'
 #                        }
 #                     ];
 #
 #   Returns:
 #
 #   string - id of the new created row
+#
 sub addMultipleService
 {
     my ($self, %params) = @_;
@@ -409,8 +431,6 @@ sub addMultipleService
                     "Couldn't get ServiceConfigurationTable");
     }
 
-
-
     $serviceConf->setDirectory($self->{'directory'} . "/$id/configuration");
 
     for my $service (@{$params{'services'}}) {
@@ -465,6 +485,96 @@ sub addMultipleService
 #
 }
 
+# Method: setMultipleService
+#
+#   Set a multi protocol service to the services table
+#
+# Parameters:
+#
+#   (NAMED)
+#
+#   name        - service's name
+#   description - service's description
+#   internal - boolean, internal services can't be modified from the UI
+#   readOnly - boolean, set the row unremovable from the UI
+#
+#   services - array ref of hash ref containing:
+#
+#	    protocol    - it can take one of these: any, tcp, udp,
+#	                                            tcp/udp, grep, icmp
+#	    sourcePort  - it can take:  "any"
+#                                   An integer from 1 to 65536 -> 22
+#                                   Two integers separated by colons -> 22:25
+#	    destinationPort - same as source
+#
+#
+#	Example:
+#
+#       'name' => 'ssh',
+#       'description' => 'secure shell'.
+#       'services' => [
+#                       {
+#	                        'protocol' => 'tcp',
+#	                        'sourcePort' => 'any',
+#                               'destinationPort' => '21:22'
+#                        },
+#                        {
+#	                        'protocol' => 'tcp',
+#	                        'sourcePort' => 'any',
+#                               'destinationPort' => '21:22'
+#                        }
+#                     ];
+#
+#   Returns:
+#
+#   string - id of the updated row
+#
+sub setMultipleService
+{
+    my ($self, %params) = @_;
+
+    my $name = $params{'name'};
+    unless (defined($name)) {
+        throw EBox::Exceptions::MissingArgument('name');
+    }
+
+    my $row = $self->findValue('name' => $name);
+    unless (defined($row)) {
+       throw EBox::Exceptions::DataNotFound('data' => 'service',
+                                            'value' => 'name');
+    }
+
+    my $id = $row->id();
+    $self->setRow(1, _serviceParams(%params), 'id' => $id);
+
+    my $serviceConf = EBox::Model::ModelManager
+                                       ->instance()
+                                       ->model('ServiceConfigurationTable');
+    unless (defined($serviceConf)) {
+        throw EBox::Exceptions::Internal(
+                    "Couldn't get ServiceConfigurationTable");
+    }
+
+    $serviceConf->setDirectory($self->{'directory'} . "/$id/configuration");
+    my @ids = @{$serviceConf->ids()};
+    unless (@ids) {
+        throw EBox::Exceptions::External(
+                "This service has no protocols configured");
+    }
+
+    for my $row (@{$serviceConf->ids()}) {
+        $serviceConf->removeRow($row);
+    }
+
+    for my $service (@{$params{'services'}}) {
+        $service->{'internal'} = $params{'internal'};
+        $service->{'readOnly'} = $params{'readOnly'};
+        $serviceConf->addRow(_serviceConfParams(%{$service}));
+    }
+
+    return $id;
+}
+
 sub _serviceParams
 {
     my (%params) = @_;
@@ -478,10 +588,9 @@ sub _serviceParams
         $translationDomain = $params{'translationDomain'};
     }
 
-   return ('name' => $name, 'description' => $description,
+    return ('name' => $name, 'description' => $description,
            'internal' => $internal, 'readOnly' => $readonly,
            'translationDomain' => $translationDomain);
-
 }
 
 sub _serviceConfParams
@@ -490,11 +599,10 @@ sub _serviceConfParams
 
     my $protocol = delete $params{'protocol'};
     my $sourcePort = delete $params{'sourcePort'};
-     my $destinationPort = delete $params{'destinationPort'};
+    my $destinationPort = delete $params{'destinationPort'};
     my $internal = $params{'internal'};
     my $readonly = $params{'readOnly'};
 
-
     my $sourcePortType;
     my $sourcePortFrom;
     my $sourcePortTo;
@@ -544,7 +652,6 @@ sub _servicesHelp
     return __('A service is an abstraction of one or more network protocols '.
               'which can be used in other modules such as: firewall, traffic '.
               'shaping...');
-
 }
 
 1;
