@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -98,10 +98,22 @@ sub _exposedMethods
            indexes  => [ 'id' ],
            },
            'updateDestPort'  => { action   => 'set',
-                                path     => [ 'ServiceTable', 'configuration' ],
-                                indexes  => [ 'name', 'id' ],
-                                selector => [ 'destination' ],
-                              },
+                                  path     => [ 'ServiceTable', 'configuration' ],
+                                  indexes  => [ 'name', 'id' ],
+                                  selector => [ 'destination' ],
+                                },
+           'addSrvConf'      => { action   => 'add',
+                                  path     => [ 'ServiceTable', 'configuration' ],
+                                  indexes  => [ 'name' ],
+                                },
+           'delSrvConf'      => { action   => 'del',
+                                  path     => [ 'ServiceTable', 'configuration' ],
+                                  indexes  => [ 'name', 'id' ],
+                                },
+           'srvConf'         => { action   => 'get',
+                                  path     => [ 'ServiceTable' ],
+                                  indexes  => [ 'name' ],
+                                },
          );
 
       return \%exposedMethods;
@@ -165,10 +177,13 @@ sub serviceNames
 #       destination - same as source
 #
 #       Example:
-#
-#            'protocol' => 'tcp',
-#            'source' => 'any',
-#       'destination' => '21:22',
+#         [
+#             {
+#              'protocol' => 'tcp',
+#               'source' => 'any',
+#               'destination' => '21:22',
+#             }
+#         ]
 sub serviceConfiguration
 {
     my ($self, $id) = @_;
@@ -207,15 +222,15 @@ sub serviceConfiguration
 #
 #   name        - service's name
 #   description - service's description
-#       protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
-#       sourcePort  - it can take:
+#   protocol    - it can take one of these: any, tcp, udp, tcp/udp, grep, icmp
+#   sourcePort  - it can take:
 #                   "any"
-#                    An integer from 1 to 65536 -> 22
+#                   An integer from 1 to 65536 -> 22
 #                   Two integers separated by colons -> 22:25
-#       destinationPort - same as source
+#   destinationPort - same as source
 #   internal - boolean, internal services can't be modified from the UI
 #   readOnly - boolean, set the row unremovable from the UI
-#   translationDomain - eBox module domain for i18n
+#   translationDomain - Zentyal module domain for i18n
 #
 #       Example:
 #
@@ -318,6 +333,57 @@ sub setService
     $self->{'serviceModel'}->setService(%params);
 }
 
+# Method: setMultipleService
+#
+#   Set a multi protocol service to the services table
+#
+# Parameters:
+#
+#   (NAMED)
+#
+#   name        - service's name
+#   description - service's description
+#   internal - boolean, internal services can't be modified from the UI
+#   readOnly - boolean, set the row unremovable from the UI
+#
+#   services - array ref of hash ref containing:
+#
+#	    protocol    - it can take one of these: any, tcp, udp,
+#	                                            tcp/udp, grep, icmp
+#	    sourcePort  - it can take:  "any"
+#                                   An integer from 1 to 65536 -> 22
+#                                   Two integers separated by colons -> 22:25
+#	    destinationPort - same as source
+#
+#
+#	Example:
+#
+#       'name' => 'ssh',
+#       'description' => 'secure shell'.
+#       'services' => [
+#                       {
+#	                        'protocol' => 'tcp',
+#	                        'sourcePort' => 'any',
+#                               'destinationPort' => '21:22'
+#                        },
+#                        {
+#	                        'protocol' => 'tcp',
+#	                        'sourcePort' => 'any',
+#                               'destinationPort' => '21:22'
+#                        }
+#                     ];
+#
+#   Returns:
+#
+#   string - id of the updated row
+#
+sub setMultipleService
+{
+    my ($self, %params) = @_;
+
+    $self->{'serviceModel'}->setMultipleService(%params);
+}
+
 # Method: setAdministrationPort
 #
 #       Set administration port on service
@@ -333,7 +399,7 @@ sub setAdministrationPort
     checkPort($port, __("port"));
 
         $self->setService('name' => __d('eBox administration'),
-                'description' => __d('eBox Administration port'),
+                'description' => __d('Zentyal Administration port'),
                 'domain' => __d('ebox-services'),
                 'protocol' => 'tcp',
                 'sourcePort' => 'any',
@@ -364,6 +430,26 @@ sub availablePort
     return $self->{'serviceModel'}->availablePort(%params);
 }
 
+# Method: serviceFromPort
+#
+#       Get the service name that it's using a port.
+#
+# Parameters:
+#
+#   (POSITIONAL)
+#   protocol   - it can take one of these: tcp, udp
+#   port       - An integer from 1 to 65536 -> 22
+#
+# Returns:
+#   string - the service name, undef otherwise
+#
+sub serviceFromPort
+{
+    my ($self, %params) = @_;
+
+    return $self->{'serviceModel'}->serviceFromPort(%params);
+}
+
 # Method: removeService
 #
 #  Remove a service from the  services table
@@ -458,7 +544,7 @@ sub serviceId
     if (not defined $row) {
         return undef;
     }
-    
+
 
     return $row->id();
 }
